@@ -1478,23 +1478,29 @@ class DividerDrawer(object):
         tabScale = artSize / self.LABEL_HEIGHT
 
         # whitespace
-        margin = padding = 2
+        safety = 1  # empty zone inside tab edge
+        padding = 3  # minimum space around text
+        margin = 0  # space for banner/frame artwork, if any
+        # most non-landscape cards have 2.5mm margins in 52.5mm banners
+        marginRatio = 2.5 / 52.5
 
         # metrics from the package assets
         cardType = card.getType()
         if artwork:
             # adjust dimensions based on the application image metrics
             bannerHeight += cardType.getTabTextHeightOffset() * tabScale
-            # adjust for space around banners and scalloped edges
-            margin = tabWidth / 18
+            # fit text inside banner/frame graphics
+            margin = (tabWidth - 2 * safety) * marginRatio
+            if card.get_GroupGlobalType() in ("Events", "Landmarks", "Projects"):
+                margin *= 1.75
 
         # cost symbol metrics
-        coinHeight = bannerHeight - 1 * tabScale
+        coinHeight = bannerHeight
         costHeight = coinHeight + 4 * tabScale
         costTop = costHeight + tabScale * 18 * 0.624  # Minion Std Black numeral height
 
         # loosely align the tops of the banner text & symbols
-        nameTop = costTop - 0.5
+        nameTop = costTop - 1
         setTop = costTop
 
         # card name metrics
@@ -1536,7 +1542,7 @@ class DividerDrawer(object):
                 imgToDraw,
                 1,
                 artHeight,
-                tabWidth - 2,
+                tabWidth - 2 * safety,
                 artSize,
                 preserveAspectRatio=False,
                 anchor="n",
@@ -1544,7 +1550,7 @@ class DividerDrawer(object):
             )
 
         # initialize margins
-        textInset = textInsetRight = margin + padding
+        textInset = textInsetRight = safety + margin
 
         # draw cost
         if (
@@ -1555,7 +1561,6 @@ class DividerDrawer(object):
             and not card.isType("Trash")
         ):
             textInset += self.drawCost(card, textInset, costHeight, scale=tabScale)
-            textInset += padding
 
         # draw set image
         if "tab" in self.options.set_icon:
@@ -1576,7 +1581,12 @@ class DividerDrawer(object):
                     self.drawSetIcon(
                         setImage, tabWidth - textInsetRight, setImageHeight
                     )
-            textInsetRight += padding
+            # leave extra room between the set icon and text
+            textInsetRight += padding / 2
+
+        # add padding between the text and any icons or margins
+        textInset += padding
+        textInsetRight += padding
 
         # draw name
         textWidth -= textInset
@@ -1665,6 +1675,13 @@ class DividerDrawer(object):
                 w = rmax
             else:  # centre, but keep it inside the margins
                 w = max(lmin, min(tabWidth / 2 - centreWidth / 2, rmax))
+            # use white text for Night cards
+            if (
+                "Night" in card.types
+                and "Action" not in card.types
+                and "Duration" not in card.types
+            ):
+                self.canvas.setFillColorRGB(1, 1, 1)
             self.drawSmallCaps(line, fontSize, w, h, style=style)
 
         self.canvas.restoreState()
